# Secureworks Microsoft Defender for Endpoint Integration Azure Infrastructure

This set of terraform templates will help your organization to create necessary
resources to onboard Microsoft Defender for Endpoint (formerly Microsoft
Defender Advanced Threat Protection, Defender ATP) with Secureworks.

1. In azure cloud bash shell (or any other preferred \*nix shell environment
   with azure-cli and terraform available), copy over all the files and place in
   an folder.
2. If not using Azure cloud shell, log into Azure using azure cli: `az login`.
   Or, if desired, log into Azure as an Azure service principal
   `az login --service-principal -u <service_principal_name> -p "<service_principal_password>" --tenant "<service_principal_tenant_id>"`
   Replacing <service_principal_name>, <service_principal_password> and
   <service_principal_tenant_id> with your organization's sepecific values.
   Using a service principal requires that service principal has appropriate
   permissions.
3. Once logged into azure in the shell, you can run the following command to
   list all the Azure region names:
   `az account list-locations --query "sort_by([].{RegionalDisplayName:regionalDisplayName, Name:name}, &RegionalDisplayName)" -o table`
   You will need the one where you want to deploy your resources (in the "Name"
   column).
4. Go into the folder in step 1. Update the terraform.tfvars file with your
   organization's short name, azure tenant_id, azure subscription_id and azure
   region short name where the resources are desired to be deployed. The
   organization's short name must not include white spaces. Update
   require_dedicated_cluster to true if it is determined that a dedicated
   cluster is needed for your organization's event volumn. Change
   data_retention_length if desired. Update azure_resource_tags accordingly if
   you want to populate tags on created Azure resources. Tags are applied on the
   resource group, eventhub dedicated cluster, and the eventhub namespace.
5. Still in the same folder in step 1, run `terraform init`. This will set up
   the terraform environment.
6. Run
   `terraform plan -out ScwxIntegration.tfplan -var-file="terraform.tfvars"`.
   This will generate the terraform execution plan that shows resources that
   will be created/updated. This also write it to the file
   ScwxIntegration.tfplan in current folder.
7. If resources the terraform executation plan looks correct, run
   `terraform apply ScwxIntegration.tfplan` to actually deploy the resources to
   Azure
8. If terraform times out when running step 6, repeat steps 5 and 6 so that
   terraform will deploy those resources failed to deploy in the previous run.
9. After the completion of `terraform apply` step, Terraform prints out the
   following entries as outputs:
   - application_id
   - application_secret
   - azure_consent_url
   - consumer_group_name
   - event_hub_name
   - event_hub_namespace
   - event_hub_namespace_resource_id
   - security_center_tenant_id
   - shared_access_policy_name
   - shared_access_policy_key
10. Please follow the url "azure_consent_url", this will consent the newly
    created Azure application's different permission requirements. The
    "event_hub_namespace_resource_id" value is for setting up data export in
    Microsoft Defender Security Center portal. Rest of the outputs are to be put
    into Secureworks portal for onboarding.

References:
https://docs.microsoft.com/en-us/azure/developer/terraform/get-started-cloud-shell#authenticate-to-azure
