# Copyright (c) 2021 Secureworks. All Rights Reserved
locals {
  resource_group_region = "${var.resource_group_name}-${var.azure_region}"
  resource_group_name   =  var.replacement_eventhub ? local.resource_group_region : azurerm_resource_group.msft-atp-resource-group[0].name
}

resource "azurerm_resource_group" "msft-atp-resource-group" {
  count    =  var.replacement_eventhub ? 0 : 1
  name     = local.resource_group_region
  location = var.azure_region
  tags = var.azure_resource_tags
}

# Note: There is no easy way to migrate a shared cluster EH namespace onto a dedicated cluster
resource "azurerm_eventhub_cluster" "msft-atp-eventhub-cluster" {
  count               = var.require_dedicated_cluster == true ? 1 : 0
  name                = "${var.client_name}-Eh-Cluster-${var.azure_region}"
  resource_group_name = local.resource_group_name
  location            = var.azure_region
  sku_name            = "Dedicated_1"

  tags = var.azure_resource_tags
}

resource "azurerm_eventhub_namespace" "msft-atp-eventhub-namespace" {
  name                     = "SCWX-TDR-Namespace-${var.client_name}-${var.azure_region}"
  resource_group_name      = local.resource_group_name
  location                 = var.azure_region
  sku                      = var.eventhub_tier
  capacity                 = var.require_dedicated_cluster == false ? (var.eventhub_tier == "Premium" ? var.eventhub_processing_units : var.eventhub_throughput_allocated) : null
  auto_inflate_enabled     = var.eventhub_tier == "Standard" ? true : null
  maximum_throughput_units = var.eventhub_tier == "Standard" ? var.eventhub_throughput_inflate_cap : null
  dedicated_cluster_id     = var.require_dedicated_cluster == true ? azurerm_eventhub_cluster.msft-atp-eventhub-cluster[0].id : null
  zone_redundant           = var.require_dedicated_cluster == true ? false : true && contains(var.eventhub_zone_redundancy_regions, var.azure_region)
  tags                     = var.azure_resource_tags
  minimum_tls_version      = 1.2
}

resource "azurerm_eventhub" "msft-atp-event-hub" {
  name                = "SCWX-TDR-EventHub"
  resource_group_name = local.resource_group_name
  namespace_name      = azurerm_eventhub_namespace.msft-atp-eventhub-namespace.name
  partition_count     = var.eventhub_partition_count
  message_retention   = var.data_retention_length
}

# This is for the stream analytics job that SCWX will create to read from the event hub
resource "azurerm_eventhub_authorization_rule" "msft-atp-event-hub-auth-rule-send" {
  name                = "SCWX-TDR-SAS"
  resource_group_name = local.resource_group_name
  namespace_name      = azurerm_eventhub_namespace.msft-atp-eventhub-namespace.name
  eventhub_name       = azurerm_eventhub.msft-atp-event-hub.name
  listen              = true
  send                = false
  manage              = false
}

resource "azurerm_eventhub_consumer_group" "msft-atp-eh-consumer_group" {
  name                = "scwx-tdr-cg-${var.client_name}"
  resource_group_name = local.resource_group_name
  namespace_name      = azurerm_eventhub_namespace.msft-atp-eventhub-namespace.name
  eventhub_name       = azurerm_eventhub.msft-atp-event-hub.name
}
